function [p,Texp,Tmax]=CRstrat(P,X)
% function [p,Texp,Tmax]=CRstrat(P,X)
% compute expected capture time given fixed strategy X
%
% P:	transition probability matrix for RW on graph G
% X:	strategy as T-by-K matrix (T length of game, K number of cops)
% p: 	prob. of robber in node n at time t  (T-by-N)
% Texp:	expected capture time
% Tmax: maximum  capture time


[T K]=size(X);
N=length(P);

PP=P;							% trans. matrix augmented with capture state
PP(N+1,N+1)=1;

Texp=inf;
Tmax=inf;

p0=ones(1,N)/N; p0(1,N+1)=0;				% random initial robber position in a non-capture state
P0=eye(N+1); 						% capture matrix for t=0
for k=1:K
	P0(X(1,k),X(1,k))=0;
	P0(X(1,k),N+1)=1;
end
p(1,:)=p0*P0;						% robber pos. probs. for t=0

for t=1:T-1						% robber pos. probs. for t>0
	PX=PP;						% build capture matrix for time t
	for k=1:K	
		i=X(t+1,k);				% k-th cop position
		if i>N; 
			break;
		end
		PX(1:N,N+1)=PX(1:N,N+1)+PX(1:N,i);
		PX(1:N,i)=zeros(N,1);
		PX(i,1:N)=zeros(1,N);
		PX(i,N+1)=1;
	end
	if i>N; 
		disp('Invalid move'); 
		break;
	end
	p(t+1,:)=p(t,:)*PX;
	if abs(1-p(t+1,N+1))<1e-10
		Tmax=t;
		break;
	end
end
if	i<=N
	[T N]=size(p);
	Texp=0;
	for t=2:T
		Texp=Texp+(t-1)*(p(t,N)-p(t-1,N));
	end
end